Ownership

Enum Ownership 

pub enum Ownership {
    Owned,
    Borrowed,
}
Determines the ownership of a temporary file or directory.

Variants



Owned

The file or directory is owned by TempFile and will be deleted when the last reference to it is dropped.



Borrowed

The file or directory is borrowed by TempFile and will be left untouched when the last reference to it is dropped.